@@ -1,5 +1,5 @@
 package Yancy::Backend::Static;
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 # ABSTRACT: Build a Yancy site from static Markdown files
 
 #pod =head1 SYNOPSIS
@@ -250,10 +250,9 @@ sub _parse_content {
     my @lines = split /\n/, decode_utf8 $content;
     # YAML frontmatter
     if ( @lines && $lines[0] =~ /^---/ ) {
-        shift @lines;
 
         # The next --- is the end of the YAML frontmatter
-        my ( $i ) = grep { $lines[ $_ ] =~ /^---/ } 0..$#lines;
+        my ( $i ) = grep { $lines[ $_ ] =~ /^---/ } 1..$#lines;
 
         # If we did not find the marker between YAML and Markdown
         if ( !defined $i ) {
@@ -267,8 +266,8 @@ sub _parse_content {
               # YAML.pm 1.29 doesn't parse 'true', 'false' as booleans
               # like the schema suggests: https://yaml.org/spec/1.2/spec.html#id2803629
               my $v = $item{$_};
-              $v = JSON::PP::false if $v eq 'false';
-              $v = JSON::PP::true if $v eq 'true';
+              $v = JSON::PP::false if $v and $v eq 'false';
+              $v = JSON::PP::true if $v and $v eq 'true';
               $v
             }} keys %item;
         };
@@ -319,7 +318,7 @@ sub _deparse_content {
         }}
         grep { !/^(?:markdown|html|path)$/ }
         keys %$item;
-    return YAML::Dump( \%data ) . "---\n". $item->{markdown};
+    return ( %data ? YAML::Dump( \%data ) . "---\n" : "") . ( $item->{markdown} // "" );
 }
 
 1;
@@ -334,7 +333,7 @@ Yancy::Backend::Static - Build a Yancy site from static Markdown files
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -401,10 +400,6 @@ Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 Wojtek Bażant <wojciech.bazant+ebi@gmail.com>
 
-=item *
-
-Wojtek Bażant <wojtek.bazant@sanger.ac.uk>
-
 =back
 
 =head1 COPYRIGHT AND LICENSE
